Class: Google::Apis::FirebasedataconnectV1::ClientCache

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Client caching settings of a connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientCache

Returns a new instance of ClientCache.



65
66
67
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 65

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_id_includedBoolean Also known as: entity_id_included?

Optional. A field that, if true, means that responses served by this connector will include entityIds in GraphQL response extensions. This helps the client SDK cache responses in an improved way, known as "normalized caching", if caching is enabled on the client. Each entityId is a stable key based on primary key values. Therefore, this field should only be set to true if the primary keys of accessed tables do not contain sensitive information. Corresponds to the JSON property entityIdIncluded

Returns:

  • (Boolean)


50
51
52
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 50

def entity_id_included
  @entity_id_included
end

#strict_validation_enabledBoolean Also known as: strict_validation_enabled?

Optional. A field that, if true, enables stricter validation on the connector source code to make sure the operation response shapes are suitable for client- side caching. This can include additional errors and warnings. For example, using the same alias for different fields is disallowed, as it may cause conflicts or confusion with normalized caching. (This field is off by default for compatibility, but enabling it is highly recommended to catch common caching pitfalls.) Corresponds to the JSON property strictValidationEnabled

Returns:

  • (Boolean)


62
63
64
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 62

def strict_validation_enabled
  @strict_validation_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70
71
72
73
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 70

def update!(**args)
  @entity_id_included = args[:entity_id_included] if args.key?(:entity_id_included)
  @strict_validation_enabled = args[:strict_validation_enabled] if args.key?(:strict_validation_enabled)
end