Class: Google::Apis::FirebasedataconnectV1::FirebaseDataConnectService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::FirebasedataconnectV1::FirebaseDataConnectService
- Defined in:
- lib/google/apis/firebasedataconnect_v1/service.rb
Overview
Firebase Data Connect API
Firebase SQL Connect is a relational database service for mobile and web apps that lets you build and scale using a fully-managed PostgreSQL database powered by Cloud SQL. The REST API lets developers manage the connections to their database, change the schema of their database, and query the database.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://firebasedataconnect.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_service(parent, service_object = nil, request_id: nil, service_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Creates a new Service in a given project and location.
-
#create_project_location_service_connector(parent, connector_object = nil, connector_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Creates a new Connector in a given project and location.
-
#create_project_location_service_schema(parent, schema_object = nil, request_id: nil, schema_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Creates a new Schema in a given project and location.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Empty
Deletes a long-running operation.
-
#delete_project_location_service(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Deletes a single Service.
-
#delete_project_location_service_connector(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Deletes a single Connector.
-
#delete_project_location_service_schema(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Deletes a single Schema.
-
#execute_connector_mutation(name, execute_mutation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ExecuteMutationResponse
Execute a predefined mutation in a Connector.
-
#execute_connector_query(name, execute_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ExecuteQueryResponse
Execute a predefined query in a Connector.
-
#execute_project_location_service_graphql(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Execute any GraphQL query or mutation against the Firebase SQL Connect's generated GraphQL schema.
-
#execute_project_location_service_graphql_read(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Execute any GraphQL query against the Firebase SQL Connect's generated GraphQL schema.
-
#generate_service_query(name, generate_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GenerateQueryResponse
Generates a GraphQL query based on a natural language prompt and the provided schema context.
-
#generate_service_schema(name, generate_schema_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GenerateSchemaResponse
Generates GraphQL schema based on a natural language prompt or data description.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Location
Gets information about a location.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Service
Gets details of a single Service.
-
#get_project_location_service_connector(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Connector
Gets details of a single Connector.
-
#get_project_location_service_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Schema
Gets details of a single Schema.
-
#impersonate_project_location_service_connector_mutation(name, impersonate_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Impersonate a mutation defined on a Firebase SQL Connect connector.
-
#impersonate_project_location_service_connector_query(name, impersonate_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Impersonate a query defined on a Firebase SQL Connect connector.
-
#initialize ⇒ FirebaseDataConnectService
constructor
A new instance of FirebaseDataConnectService.
-
#introspect_project_location_service_graphql(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Execute introspection query against the Firebase SQL Connect's generated GraphQL schema.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_service_connectors(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListConnectorsResponse
Lists Connectors in a given project and location.
-
#list_project_location_service_schemas(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListSchemasResponse
Lists Schemas in a given project and location.
-
#list_project_location_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListServicesResponse
Lists Services in a given project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_service(name, service_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Updates the parameters of a single Service.
-
#patch_project_location_service_connector(name, connector_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Updates the parameters of a single Connector, and creates a new ConnectorRevision with the updated Connector.
-
#patch_project_location_service_schema(name, schema_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Updates the parameters of a single Schema, and creates a new SchemaRevision with the updated Schema.
Constructor Details
#initialize ⇒ FirebaseDataConnectService
Returns a new instance of FirebaseDataConnectService.
50 51 52 53 54 55 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 50 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-firebasedataconnect_v1', client_version: Google::Apis::FirebasedataconnectV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
43 44 45 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 43 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
48 49 50 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 48 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 171 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::FirebasedataconnectV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::Empty::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_service(parent, service_object = nil, request_id: nil, service_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Creates a new Service in a given project and location.
334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 334 def create_project_location_service(parent, service_object = nil, request_id: nil, service_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/services', ) command.request_representation = Google::Apis::FirebasedataconnectV1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['serviceId'] = service_id unless service_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_service_connector(parent, connector_object = nil, connector_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Creates a new Connector in a given project and location. The operations are validated against and must be compatible with the active schema. If the operations and schema are not compatible or if the schema is not present, this will result in an error.
775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 775 def create_project_location_service_connector(parent, connector_object = nil, connector_id: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/connectors', ) command.request_representation = Google::Apis::FirebasedataconnectV1::Connector::Representation command.request_object = connector_object command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['parent'] = parent unless parent.nil? command.query['connectorId'] = connector_id unless connector_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_service_schema(parent, schema_object = nil, request_id: nil, schema_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Creates a new Schema in a given project and location. Only creation of
schemas/main is supported and calling create with any other schema ID will
result in an error.
1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 1180 def create_project_location_service_schema(parent, schema_object = nil, request_id: nil, schema_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/schemas', ) command.request_representation = Google::Apis::FirebasedataconnectV1::Schema::Representation command.request_object = schema_object command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['schemaId'] = schema_id unless schema_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
206 207 208 209 210 211 212 213 214 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 206 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Empty::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_service(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Deletes a single Service.
394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 394 def delete_project_location_service(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['etag'] = etag unless etag.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_service_connector(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Deletes a single Connector.
835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 835 def delete_project_location_service_connector(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['etag'] = etag unless etag.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_service_schema(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Deletes a single Schema. Because the schema and connectors must be compatible at all times, if this is called while any connectors are active, this will result in an error.
1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 1241 def delete_project_location_service_schema(name, allow_missing: nil, etag: nil, force: nil, request_id: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['etag'] = etag unless etag.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_connector_mutation(name, execute_mutation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ExecuteMutationResponse
Execute a predefined mutation in a Connector.
873 874 875 876 877 878 879 880 881 882 883 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 873 def execute_connector_mutation(name, execute_mutation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:executeMutation', ) command.request_representation = Google::Apis::FirebasedataconnectV1::ExecuteMutationRequest::Representation command.request_object = execute_mutation_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::ExecuteMutationResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::ExecuteMutationResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_connector_query(name, execute_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ExecuteQueryResponse
Execute a predefined query in a Connector.
908 909 910 911 912 913 914 915 916 917 918 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 908 def execute_connector_query(name, execute_query_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:executeQuery', ) command.request_representation = Google::Apis::FirebasedataconnectV1::ExecuteQueryRequest::Representation command.request_object = execute_query_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::ExecuteQueryResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::ExecuteQueryResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_project_location_service_graphql(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Execute any GraphQL query or mutation against the Firebase SQL Connect's generated GraphQL schema. Grants full read and write access to the connected data sources. Note: Use introspection query to explore the generated GraphQL schema.
434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 434 def execute_project_location_service_graphql(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:executeGraphql', ) command.request_representation = Google::Apis::FirebasedataconnectV1::GraphqlRequest::Representation command.request_object = graphql_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::GraphqlResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::GraphqlResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_project_location_service_graphql_read(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Execute any GraphQL query against the Firebase SQL Connect's generated GraphQL
schema. Grants full read to the connected data sources. ExecuteGraphqlRead
is identical to ExecuteGraphql except it only accepts read-only query.
470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 470 def execute_project_location_service_graphql_read(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:executeGraphqlRead', ) command.request_representation = Google::Apis::FirebasedataconnectV1::GraphqlRequest::Representation command.request_object = graphql_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::GraphqlResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::GraphqlResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_service_query(name, generate_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GenerateQueryResponse
Generates a GraphQL query based on a natural language prompt and the provided schema context. This is a stateless method; the schema is provided per request to support local development states. Streams results with real-time status and output chunks.
507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 507 def generate_service_query(name, generate_query_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:generateQuery', ) command.request_representation = Google::Apis::FirebasedataconnectV1::GenerateQueryRequest::Representation command.request_object = generate_query_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::GenerateQueryResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::GenerateQueryResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_service_schema(name, generate_schema_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GenerateSchemaResponse
Generates GraphQL schema based on a natural language prompt or data description. This allows users to scaffold new types and tables quickly. Streams results with real-time status and output chunks.
543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 543 def generate_service_schema(name, generate_schema_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:generateSchema', ) command.request_representation = Google::Apis::FirebasedataconnectV1::GenerateSchemaRequest::Representation command.request_object = generate_schema_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::GenerateSchemaResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::GenerateSchemaResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Location
Gets information about a location.
77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 77 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Location::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
237 238 239 240 241 242 243 244 245 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 237 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Service
Gets details of a single Service.
576 577 578 579 580 581 582 583 584 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 576 def get_project_location_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Service::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Service command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_service_connector(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Connector
Gets details of a single Connector.
941 942 943 944 945 946 947 948 949 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 941 def get_project_location_service_connector(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Connector::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Connector command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_service_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Schema
Gets details of a single Schema.
1277 1278 1279 1280 1281 1282 1283 1284 1285 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 1277 def get_project_location_service_schema(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::FirebasedataconnectV1::Schema::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Schema command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#impersonate_project_location_service_connector_mutation(name, impersonate_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Impersonate a mutation defined on a Firebase SQL Connect connector. It grants the admin SDK access to mutations defined in the given connector. The caller can choose to impersonate a particular Firebase Auth user, or skip @auth completely.
977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 977 def impersonate_project_location_service_connector_mutation(name, impersonate_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:impersonateMutation', ) command.request_representation = Google::Apis::FirebasedataconnectV1::ImpersonateRequest::Representation command.request_object = impersonate_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::GraphqlResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::GraphqlResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#impersonate_project_location_service_connector_query(name, impersonate_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Impersonate a query defined on a Firebase SQL Connect connector. It grants the admin SDK access to queries defined in the given connector. The caller can choose to impersonate a particular Firebase Auth user, or skip @auth completely.
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 1015 def impersonate_project_location_service_connector_query(name, impersonate_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:impersonateQuery', ) command.request_representation = Google::Apis::FirebasedataconnectV1::ImpersonateRequest::Representation command.request_object = impersonate_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::GraphqlResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::GraphqlResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#introspect_project_location_service_graphql(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponse
Execute introspection query against the Firebase SQL Connect's generated GraphQL schema. GraphQL introspection query provides metadata such as what tables the schema have, what queries and mutations can be performed on the schema, and so on. Read more at https://graphql.org/learn/introspection. IntrospectGraphql can read schema metadata but cannot read rows from Cloud SQL instance, which can be done via ExecuteGraphqlRead.
613 614 615 616 617 618 619 620 621 622 623 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 613 def introspect_project_location_service_graphql(name, graphql_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:introspectGraphql', ) command.request_representation = Google::Apis::FirebasedataconnectV1::GraphqlRequest::Representation command.request_object = graphql_request_object command.response_representation = Google::Apis::FirebasedataconnectV1::GraphqlResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::GraphqlResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 282 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::FirebasedataconnectV1::ListOperationsResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_service_connectors(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListConnectorsResponse
Lists Connectors in a given project and location.
1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 1059 def list_project_location_service_connectors(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/connectors', ) command.response_representation = Google::Apis::FirebasedataconnectV1::ListConnectorsResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::ListConnectorsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_service_schemas(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListSchemasResponse
Lists Schemas in a given project and location.
1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 1318 def list_project_location_service_schemas(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/schemas', ) command.response_representation = Google::Apis::FirebasedataconnectV1::ListSchemasResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::ListSchemasResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListServicesResponse
Lists Services in a given project and location.
656 657 658 659 660 661 662 663 664 665 666 667 668 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 656 def list_project_location_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/services', ) command.response_representation = Google::Apis::FirebasedataconnectV1::ListServicesResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::ListServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 129 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::FirebasedataconnectV1::ListLocationsResponse::Representation command.response_class = Google::Apis::FirebasedataconnectV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_service(name, service_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Updates the parameters of a single Service.
718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 718 def patch_project_location_service(name, service_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FirebasedataconnectV1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_service_connector(name, connector_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Updates the parameters of a single Connector, and creates a new ConnectorRevision with the updated Connector. The operations are validated against and must be compatible with the live schema. If the operations and schema are not compatible or if the schema is not present, this will result in an error.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 1123 def patch_project_location_service_connector(name, connector_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FirebasedataconnectV1::Connector::Representation command.request_object = connector_object command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_service_schema(name, schema_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebasedataconnectV1::Operation
Updates the parameters of a single Schema, and creates a new SchemaRevision with the updated Schema.
1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 |
# File 'lib/google/apis/firebasedataconnect_v1/service.rb', line 1379 def patch_project_location_service_schema(name, schema_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::FirebasedataconnectV1::Schema::Representation command.request_object = schema_object command.response_representation = Google::Apis::FirebasedataconnectV1::Operation::Representation command.response_class = Google::Apis::FirebasedataconnectV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |