Class: Google::Apis::FirebasedataconnectV1::GenerateQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Request message for GenerateQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateQueryRequest

Returns a new instance of GenerateQueryRequest.



450
451
452
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#promptString

Required. The natural language description of the desired query. Example: " Find all users who signed up in the last 7 days." Corresponds to the JSON property prompt

Returns:

  • (String)


442
443
444
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 442

def prompt
  @prompt
end

#schemasArray<Google::Apis::FirebasedataconnectV1::Schema>

Optional. The user's locally defined FDC Schema(s). If not defined, the backend will fetch the user's deployed schema. Corresponds to the JSON property schemas



448
449
450
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 448

def schemas
  @schemas
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



455
456
457
458
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 455

def update!(**args)
  @prompt = args[:prompt] if args.key?(:prompt)
  @schemas = args[:schemas] if args.key?(:schemas)
end