Class: Google::Apis::FirebasedataconnectV1::GenerateQueryResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::GenerateQueryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
Output for streaming generate query requests
Instance Attribute Summary collapse
-
#part ⇒ Google::Apis::FirebasedataconnectV1::Part
Represents a chunk of content.
-
#status ⇒ Google::Apis::FirebasedataconnectV1::GenerationStatus
Represents the progress of the server side generation request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateQueryResponse
constructor
A new instance of GenerateQueryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateQueryResponse
Returns a new instance of GenerateQueryResponse.
475 476 477 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 475 def initialize(**args) update!(**args) end |
Instance Attribute Details
#part ⇒ Google::Apis::FirebasedataconnectV1::Part
Represents a chunk of content.
Corresponds to the JSON property part
468 469 470 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 468 def part @part end |
#status ⇒ Google::Apis::FirebasedataconnectV1::GenerationStatus
Represents the progress of the server side generation request.
Corresponds to the JSON property status
473 474 475 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 473 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
480 481 482 483 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 480 def update!(**args) @part = args[:part] if args.key?(:part) @status = args[:status] if args.key?(:status) end |