Class: Google::Apis::FirebasedataconnectV1::GraphqlResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::GraphqlResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
The GraphQL response from Firebase SQL Connect. It strives to match the
GraphQL over HTTP spec. Note: Firebase SQL Connect always responds with
Content-Type: application/json. https://github.com/graphql/graphql-over-http/
blob/main/spec/GraphQLOverHTTP.md#body
Instance Attribute Summary collapse
-
#data ⇒ Hash<String,Object>
The result of the execution of the requested operation.
-
#errors ⇒ Array<Google::Apis::FirebasedataconnectV1::GraphqlError>
Errors of this response.
-
#extensions ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponseExtensions
GraphqlResponseExtensions contains additional information of
GraphqlResponseorExecuteQueryResponse.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GraphqlResponse
constructor
A new instance of GraphqlResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GraphqlResponse
Returns a new instance of GraphqlResponse.
754 755 756 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 754 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Hash<String,Object>
The result of the execution of the requested operation. If an error was raised
before execution begins, the data entry should not be present in the result. (
a request error: https://spec.graphql.org/draft/#sec-Errors.Request-Errors) If
an error was raised during the execution that prevented a valid response, the
data entry in the response should be null. (a field error: https://spec.
graphql.org/draft/#sec-Errors.Error-Result-Format)
Corresponds to the JSON property data
739 740 741 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 739 def data @data end |
#errors ⇒ Array<Google::Apis::FirebasedataconnectV1::GraphqlError>
Errors of this response. If the data entry in the response is not present, the
errors entry must be present. It conforms to https://spec.graphql.org/draft/#
sec-Errors .
Corresponds to the JSON property errors
746 747 748 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 746 def errors @errors end |
#extensions ⇒ Google::Apis::FirebasedataconnectV1::GraphqlResponseExtensions
GraphqlResponseExtensions contains additional information of GraphqlResponse
or ExecuteQueryResponse.
Corresponds to the JSON property extensions
752 753 754 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 752 def extensions @extensions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
759 760 761 762 763 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 759 def update!(**args) @data = args[:data] if args.key?(:data) @errors = args[:errors] if args.key?(:errors) @extensions = args[:extensions] if args.key?(:extensions) end |