Class: Google::Apis::FirebasedataconnectV1::ListConnectorsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Message for response to listing Connectors. By default, connectors.source will not be included in the response. To specify the fields included in the response, the response field mask can be provided by using the query parameter $fields or the header X-Goog-FieldMask.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListConnectorsResponse

Returns a new instance of ListConnectorsResponse.



910
911
912
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectorsArray<Google::Apis::FirebasedataconnectV1::Connector>

The list of Connectors. Corresponds to the JSON property connectors



897
898
899
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 897

def connectors
  @connectors
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


903
904
905
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 903

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


908
909
910
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 908

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



915
916
917
918
919
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 915

def update!(**args)
  @connectors = args[:connectors] if args.key?(:connectors)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end