Class: Google::Apis::FirebasedataconnectV1::ListSchemasResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Message for response to listing Schemas. By default, schemas.source will not be included in the response. To specify the fields included in the response, the response field mask can be provided by using the query parameter $fields or the header X-Goog-FieldMask.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSchemasResponse

Returns a new instance of ListSchemasResponse.



998
999
1000
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


986
987
988
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 986

def next_page_token
  @next_page_token
end

#schemasArray<Google::Apis::FirebasedataconnectV1::Schema>

The list of Schemas. Corresponds to the JSON property schemas



991
992
993
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 991

def schemas
  @schemas
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


996
997
998
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 996

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1003
1004
1005
1006
1007
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1003

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @schemas = args[:schemas] if args.key?(:schemas)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end