Class: Google::Apis::FirebasedataconnectV1::Schema
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
The application schema of a Firebase SQL Connect service.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#datasources ⇒ Array<Google::Apis::FirebasedataconnectV1::Datasource>
Required.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#source ⇒ Google::Apis::FirebasedataconnectV1::Source
Used to represent a set of source files.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schema
constructor
A new instance of Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schema
Returns a new instance of Schema.
1383 1384 1385 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Stores small amounts of arbitrary data.
Corresponds to the JSON property annotations
1324 1325 1326 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1324 def annotations @annotations end |
#create_time ⇒ String
Output only. [Output only] Create time stamp.
Corresponds to the JSON property createTime
1329 1330 1331 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1329 def create_time @create_time end |
#datasources ⇒ Array<Google::Apis::FirebasedataconnectV1::Datasource>
Required. The data sources linked in the schema.
Corresponds to the JSON property datasources
1334 1335 1336 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1334 def datasources @datasources end |
#display_name ⇒ String
Optional. Mutable human-readable name. 63 character limit.
Corresponds to the JSON property displayName
1339 1340 1341 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1339 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding. AIP-154
Corresponds to the JSON property etag
1347 1348 1349 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1347 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
1352 1353 1354 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1352 def labels @labels end |
#name ⇒ String
Identifier. The relative resource name of the schema, in the format:
projects/`project`/locations/`location`/services/`service`/schemas/`schema`
Right now, the only supported schema is "main".
Corresponds to the JSON property name
1359 1360 1361 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1359 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. A field that if true, indicates that the system is working to
compile and deploy the schema.
Corresponds to the JSON property reconciling
1365 1366 1367 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1365 def reconciling @reconciling end |
#source ⇒ Google::Apis::FirebasedataconnectV1::Source
Used to represent a set of source files.
Corresponds to the JSON property source
1371 1372 1373 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1371 def source @source end |
#uid ⇒ String
Output only. System-assigned, unique identifier.
Corresponds to the JSON property uid
1376 1377 1378 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1376 def uid @uid end |
#update_time ⇒ String
Output only. [Output only] Update time stamp.
Corresponds to the JSON property updateTime
1381 1382 1383 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1381 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1388 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @datasources = args[:datasources] if args.key?(:datasources) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @source = args[:source] if args.key?(:source) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |