Class: Google::Apis::FirebasedataconnectV1::Service
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
A Firebase SQL Connect service.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
1461 1462 1463 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Stores small amounts of arbitrary data.
Corresponds to the JSON property annotations
1410 1411 1412 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1410 def annotations @annotations end |
#create_time ⇒ String
Output only. [Output only] Create time stamp.
Corresponds to the JSON property createTime
1415 1416 1417 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1415 def create_time @create_time end |
#display_name ⇒ String
Optional. Mutable human-readable name. 63 character limit.
Corresponds to the JSON property displayName
1420 1421 1422 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1420 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding. AIP-154
Corresponds to the JSON property etag
1428 1429 1430 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1428 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
1433 1434 1435 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1433 def labels @labels end |
#name ⇒ String
Identifier. The relative resource name of the Firebase SQL Connect service, in
the format: projects/`project`/locations/`location`/services/`service`
Note that the service ID is specific to Firebase SQL Connect and does not
correspond to any of the instance IDs of the underlying data source
connections.
Corresponds to the JSON property name
1442 1443 1444 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1442 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. A field that if true, indicates that the system is working update
the service.
Corresponds to the JSON property reconciling
1448 1449 1450 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1448 def reconciling @reconciling end |
#uid ⇒ String
Output only. System-assigned, unique identifier.
Corresponds to the JSON property uid
1454 1455 1456 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1454 def uid @uid end |
#update_time ⇒ String
Output only. [Output only] Update time stamp.
Corresponds to the JSON property updateTime
1459 1460 1461 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1459 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1466 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |