Class: Google::Apis::FirebasedataconnectV1::Workaround
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::Workaround
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
Workaround provides suggestions to address errors and warnings.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of this workaround.
-
#reason ⇒ String
Why would this workaround address the error and warning.
-
#replace ⇒ String
A suggested code snippet to fix the error and warning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Workaround
constructor
A new instance of Workaround.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Workaround
Returns a new instance of Workaround.
1594 1595 1596 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description of this workaround.
Corresponds to the JSON property description
1582 1583 1584 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1582 def description @description end |
#reason ⇒ String
Why would this workaround address the error and warning.
Corresponds to the JSON property reason
1587 1588 1589 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1587 def reason @reason end |
#replace ⇒ String
A suggested code snippet to fix the error and warning.
Corresponds to the JSON property replace
1592 1593 1594 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1592 def replace @replace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1599 1600 1601 1602 1603 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1599 def update!(**args) @description = args[:description] if args.key?(:description) @reason = args[:reason] if args.key?(:reason) @replace = args[:replace] if args.key?(:replace) end |