Class: Google::Apis::FirebasedataconnectV1::Connector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Connector consists of a set of operations, i.e. queries and mutations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Connector

Returns a new instance of Connector.



188
189
190
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Stores small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


129
130
131
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 129

def annotations
  @annotations
end

#client_cacheGoogle::Apis::FirebasedataconnectV1::ClientCache

Client caching settings of a connector. Corresponds to the JSON property clientCache



134
135
136
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 134

def client_cache
  @client_cache
end

#create_timeString

Output only. [Output only] Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


139
140
141
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 139

def create_time
  @create_time
end

#display_nameString

Optional. Mutable human-readable name. 63 character limit. Corresponds to the JSON property displayName

Returns:

  • (String)


144
145
146
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 144

def display_name
  @display_name
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. AIP-154 Corresponds to the JSON property etag

Returns:

  • (String)


152
153
154
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 152

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


157
158
159
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 157

def labels
  @labels
end

#nameString

Identifier. The relative resource name of the connector, in the format: projects/`project`/locations/`location`/services/`service`/connectors/` connector` Corresponds to the JSON property name

Returns:

  • (String)


164
165
166
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 164

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that if true, indicates that the system is working to compile and deploy the connector. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


170
171
172
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 170

def reconciling
  @reconciling
end

#sourceGoogle::Apis::FirebasedataconnectV1::Source

Used to represent a set of source files. Corresponds to the JSON property source



176
177
178
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 176

def source
  @source
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


181
182
183
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 181

def uid
  @uid
end

#update_timeString

Output only. [Output only] Update time stamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


186
187
188
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 186

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 193

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @client_cache = args[:client_cache] if args.key?(:client_cache)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @source = args[:source] if args.key?(:source)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end