Class: Google::Apis::FirebasedataconnectV1::Connector
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::Connector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
Connector consists of a set of operations, i.e. queries and mutations.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#client_cache ⇒ Google::Apis::FirebasedataconnectV1::ClientCache
Client caching settings of a connector.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#source ⇒ Google::Apis::FirebasedataconnectV1::Source
Used to represent a set of source files.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Connector
constructor
A new instance of Connector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Connector
Returns a new instance of Connector.
188 189 190 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 188 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Stores small amounts of arbitrary data.
Corresponds to the JSON property annotations
129 130 131 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 129 def annotations @annotations end |
#client_cache ⇒ Google::Apis::FirebasedataconnectV1::ClientCache
Client caching settings of a connector.
Corresponds to the JSON property clientCache
134 135 136 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 134 def client_cache @client_cache end |
#create_time ⇒ String
Output only. [Output only] Create time stamp.
Corresponds to the JSON property createTime
139 140 141 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 139 def create_time @create_time end |
#display_name ⇒ String
Optional. Mutable human-readable name. 63 character limit.
Corresponds to the JSON property displayName
144 145 146 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 144 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding. AIP-154
Corresponds to the JSON property etag
152 153 154 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 152 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
157 158 159 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 157 def labels @labels end |
#name ⇒ String
Identifier. The relative resource name of the connector, in the format:
projects/`project`/locations/`location`/services/`service`/connectors/`
connector`
Corresponds to the JSON property name
164 165 166 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 164 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. A field that if true, indicates that the system is working to
compile and deploy the connector.
Corresponds to the JSON property reconciling
170 171 172 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 170 def reconciling @reconciling end |
#source ⇒ Google::Apis::FirebasedataconnectV1::Source
Used to represent a set of source files.
Corresponds to the JSON property source
176 177 178 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 176 def source @source end |
#uid ⇒ String
Output only. System-assigned, unique identifier.
Corresponds to the JSON property uid
181 182 183 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 181 def uid @uid end |
#update_time ⇒ String
Output only. [Output only] Update time stamp.
Corresponds to the JSON property updateTime
186 187 188 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 186 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 193 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @client_cache = args[:client_cache] if args.key?(:client_cache) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @source = args[:source] if args.key?(:source) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |