Class: Google::Apis::FirebasedataconnectV1::Connector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Connector consists of a set of operations, i.e. queries and mutations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Connector

Returns a new instance of Connector.



162
163
164
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Stores small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


103
104
105
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 103

def annotations
  @annotations
end

#client_cacheGoogle::Apis::FirebasedataconnectV1::ClientCache

Client caching settings of a connector. Corresponds to the JSON property clientCache



108
109
110
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 108

def client_cache
  @client_cache
end

#create_timeString

Output only. [Output only] Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


113
114
115
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 113

def create_time
  @create_time
end

#display_nameString

Optional. Mutable human-readable name. 63 character limit. Corresponds to the JSON property displayName

Returns:

  • (String)


118
119
120
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 118

def display_name
  @display_name
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. AIP-154 Corresponds to the JSON property etag

Returns:

  • (String)


126
127
128
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 126

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


131
132
133
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 131

def labels
  @labels
end

#nameString

Identifier. The relative resource name of the connector, in the format: projects/`project`/locations/`location`/services/`service`/connectors/` connector` Corresponds to the JSON property name

Returns:

  • (String)


138
139
140
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 138

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that if true, indicates that the system is working to compile and deploy the connector. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


144
145
146
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 144

def reconciling
  @reconciling
end

#sourceGoogle::Apis::FirebasedataconnectV1::Source

Used to represent a set of source files. Corresponds to the JSON property source



150
151
152
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 150

def source
  @source
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


155
156
157
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 155

def uid
  @uid
end

#update_timeString

Output only. [Output only] Update time stamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


160
161
162
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 160

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 167

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @client_cache = args[:client_cache] if args.key?(:client_cache)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @source = args[:source] if args.key?(:source)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end