Class: Google::Apis::FirebasedataconnectV1::DataConnectProperties
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::DataConnectProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
SQL Connect specific properties for a path under response.data.
Instance Attribute Summary collapse
-
#entity_id ⇒ String
A single Entity ID.
-
#entity_ids ⇒ Array<String>
A list of Entity IDs.
-
#max_age ⇒ String
The server-suggested duration before data under path is considered stale.
-
#path ⇒ Array<Object>
The path under response.data where the rest of the fields apply.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataConnectProperties
constructor
A new instance of DataConnectProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataConnectProperties
Returns a new instance of DataConnectProperties.
241 242 243 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity_id ⇒ String
A single Entity ID. Set if the path points to a single entity.
Corresponds to the JSON property entityId
221 222 223 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 221 def entity_id @entity_id end |
#entity_ids ⇒ Array<String>
A list of Entity IDs. Set if the path points to an array of entities. An ID is
present for each element of the array at the corresponding index.
Corresponds to the JSON property entityIds
227 228 229 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 227 def entity_ids @entity_ids end |
#max_age ⇒ String
The server-suggested duration before data under path is considered stale.
Corresponds to the JSON property maxAge
232 233 234 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 232 def max_age @max_age end |
#path ⇒ Array<Object>
The path under response.data where the rest of the fields apply. Each element
may be a string (field name) or number (array index). The root of response.
data is denoted by the empty list [].
Corresponds to the JSON property path
239 240 241 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 239 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
246 247 248 249 250 251 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 246 def update!(**args) @entity_id = args[:entity_id] if args.key?(:entity_id) @entity_ids = args[:entity_ids] if args.key?(:entity_ids) @max_age = args[:max_age] if args.key?(:max_age) @path = args[:path] if args.key?(:path) end |