Class: Google::Apis::FirebasedataconnectV1::GraphqlErrorExtensions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

GraphqlErrorExtensions contains additional information of GraphqlError.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GraphqlErrorExtensions

Returns a new instance of GraphqlErrorExtensions.



501
502
503
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Maps to canonical gRPC codes. If not specified, it represents Code.INTERNAL. Corresponds to the JSON property code

Returns:

  • (String)


471
472
473
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 471

def code
  @code
end

#debug_detailsString

More detailed error message to assist debugging. It contains application business logic that are inappropriate to leak publicly. In the emulator, Data Connect API always includes it to assist local development and debugging. In the backend, ConnectorService always hides it. GraphqlService without impersonation always include it. GraphqlService with impersonation includes it only if explicitly opted-in with include_debug_details in GraphqlRequestExtensions. Corresponds to the JSON property debugDetails

Returns:

  • (String)


482
483
484
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 482

def debug_details
  @debug_details
end

#fileString

The source file name where the error occurred. Included only for UpdateSchema and UpdateConnector, it corresponds to File.path of the provided Source. Corresponds to the JSON property file

Returns:

  • (String)


488
489
490
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 488

def file
  @file
end

#warning_levelString

Warning level describes the severity and required action to suppress this warning when Firebase CLI run into it. Corresponds to the JSON property warningLevel

Returns:

  • (String)


494
495
496
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 494

def warning_level
  @warning_level
end

#workaroundsArray<Google::Apis::FirebasedataconnectV1::Workaround>

Workarounds provide suggestions to address the compile errors or warnings. Corresponds to the JSON property workarounds



499
500
501
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 499

def workarounds
  @workarounds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



506
507
508
509
510
511
512
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 506

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @debug_details = args[:debug_details] if args.key?(:debug_details)
  @file = args[:file] if args.key?(:file)
  @warning_level = args[:warning_level] if args.key?(:warning_level)
  @workarounds = args[:workarounds] if args.key?(:workarounds)
end