Class: Google::Apis::FirebasedataconnectV1::PostgreSql
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::PostgreSql
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
Settings for PostgreSQL data source.
Instance Attribute Summary collapse
-
#cloud_sql ⇒ Google::Apis::FirebasedataconnectV1::CloudSqlInstance
Settings for CloudSQL instance configuration.
-
#database ⇒ String
Required.
-
#ephemeral ⇒ Boolean
(also: #ephemeral?)
Output only.
-
#schema ⇒ String
Optional.
-
#schema_migration ⇒ String
Optional.
-
#schema_validation ⇒ String
Optional.
-
#unlinked ⇒ Boolean
(also: #unlinked?)
No Postgres data source is linked.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostgreSql
constructor
A new instance of PostgreSql.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostgreSql
Returns a new instance of PostgreSql.
1301 1302 1303 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_sql ⇒ Google::Apis::FirebasedataconnectV1::CloudSqlInstance
Settings for CloudSQL instance configuration.
Corresponds to the JSON property cloudSql
1254 1255 1256 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1254 def cloud_sql @cloud_sql end |
#database ⇒ String
Required. Name of the PostgreSQL database.
Corresponds to the JSON property database
1259 1260 1261 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1259 def database @database end |
#ephemeral ⇒ Boolean Also known as: ephemeral?
Output only. Ephemeral is true if this SQL Connect service is served from
temporary in-memory emulation of Postgres. While Cloud SQL is being
provisioned, the SQL Connect service provides the ephemeral service to help
developers get started. Once the Cloud SQL is provisioned, SQL Connect service
will transfer its data on a best-effort basis to the Cloud SQL instance.
WARNING: Ephemeral data sources will expire after 24 hour. The data will be
lost if they aren't transferred to the Cloud SQL instance. WARNING: When
ephemeral=true, mutations to the database are not guaranteed to be durably
persisted, even if an OK status code is returned. All or parts of the data may
be lost or reverted to earlier versions.
Corresponds to the JSON property ephemeral
1273 1274 1275 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1273 def ephemeral @ephemeral end |
#schema ⇒ String
Optional. User-configured PostgreSQL schema. Defaults to "public" if not
specified.
Corresponds to the JSON property schema
1280 1281 1282 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1280 def schema @schema end |
#schema_migration ⇒ String
Optional. Configure how to perform automatic PostgreSQL schema migration
before deploying the FDC schema. This is an additive-only operation.
Corresponds to the JSON property schemaMigration
1286 1287 1288 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1286 def schema_migration @schema_migration end |
#schema_validation ⇒ String
Optional. Configure how much PostgreSQL schema validation to perform against
the live database before deploying the FDC schema.
Corresponds to the JSON property schemaValidation
1292 1293 1294 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1292 def schema_validation @schema_validation end |
#unlinked ⇒ Boolean Also known as: unlinked?
No Postgres data source is linked. If set, don't allow database and
schema_validation to be configured.
Corresponds to the JSON property unlinked
1298 1299 1300 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1298 def unlinked @unlinked end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1306 1307 1308 1309 1310 1311 1312 1313 1314 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1306 def update!(**args) @cloud_sql = args[:cloud_sql] if args.key?(:cloud_sql) @database = args[:database] if args.key?(:database) @ephemeral = args[:ephemeral] if args.key?(:ephemeral) @schema = args[:schema] if args.key?(:schema) @schema_migration = args[:schema_migration] if args.key?(:schema_migration) @schema_validation = args[:schema_validation] if args.key?(:schema_validation) @unlinked = args[:unlinked] if args.key?(:unlinked) end |