Class: Google::Apis::FirebasedataconnectV1::PostgreSql

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Settings for PostgreSQL data source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgreSql

Returns a new instance of PostgreSql.



1295
1296
1297
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sqlGoogle::Apis::FirebasedataconnectV1::CloudSqlInstance

Settings for CloudSQL instance configuration. Corresponds to the JSON property cloudSql



1248
1249
1250
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1248

def cloud_sql
  @cloud_sql
end

#databaseString

Required. Name of the PostgreSQL database. Corresponds to the JSON property database

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1253

def database
  @database
end

#ephemeralBoolean Also known as: ephemeral?

Output only. Ephemeral is true if this SQL Connect service is served from temporary in-memory emulation of Postgres. While Cloud SQL is being provisioned, the SQL Connect service provides the ephemeral service to help developers get started. Once the Cloud SQL is provisioned, SQL Connect service will transfer its data on a best-effort basis to the Cloud SQL instance. WARNING: Ephemeral data sources will expire after 24 hour. The data will be lost if they aren't transferred to the Cloud SQL instance. WARNING: When ephemeral=true, mutations to the database are not guaranteed to be durably persisted, even if an OK status code is returned. All or parts of the data may be lost or reverted to earlier versions. Corresponds to the JSON property ephemeral

Returns:

  • (Boolean)


1267
1268
1269
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1267

def ephemeral
  @ephemeral
end

#schemaString

Optional. User-configured PostgreSQL schema. Defaults to "public" if not specified. Corresponds to the JSON property schema

Returns:

  • (String)


1274
1275
1276
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1274

def schema
  @schema
end

#schema_migrationString

Optional. Configure how to perform automatic PostgreSQL schema migration before deploying the FDC schema. This is an additive-only operation. Corresponds to the JSON property schemaMigration

Returns:

  • (String)


1280
1281
1282
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1280

def schema_migration
  @schema_migration
end

#schema_validationString

Optional. Configure how much PostgreSQL schema validation to perform against the live database before deploying the FDC schema. Corresponds to the JSON property schemaValidation

Returns:

  • (String)


1286
1287
1288
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1286

def schema_validation
  @schema_validation
end

#unlinkedBoolean Also known as: unlinked?

No Postgres data source is linked. If set, don't allow database and schema_validation to be configured. Corresponds to the JSON property unlinked

Returns:

  • (Boolean)


1292
1293
1294
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1292

def unlinked
  @unlinked
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1300
1301
1302
1303
1304
1305
1306
1307
1308
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1300

def update!(**args)
  @cloud_sql = args[:cloud_sql] if args.key?(:cloud_sql)
  @database = args[:database] if args.key?(:database)
  @ephemeral = args[:ephemeral] if args.key?(:ephemeral)
  @schema = args[:schema] if args.key?(:schema)
  @schema_migration = args[:schema_migration] if args.key?(:schema_migration)
  @schema_validation = args[:schema_validation] if args.key?(:schema_validation)
  @unlinked = args[:unlinked] if args.key?(:unlinked)
end