Class: Google::Apis::FirebasedataconnectV1::PostgreSql

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Settings for PostgreSQL data source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgreSql

Returns a new instance of PostgreSql.



1119
1120
1121
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sqlGoogle::Apis::FirebasedataconnectV1::CloudSqlInstance

Settings for CloudSQL instance configuration. Corresponds to the JSON property cloudSql



1074
1075
1076
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1074

def cloud_sql
  @cloud_sql
end

#databaseString

Required. Name of the PostgreSQL database. Corresponds to the JSON property database

Returns:

  • (String)


1079
1080
1081
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1079

def database
  @database
end

#ephemeralBoolean Also known as: ephemeral?

Output only. Ephemeral is true if this data connect service is served from temporary in-memory emulation of Postgres. While Cloud SQL is being provisioned, the data connect service provides the ephemeral service to help developers get started. Once the Cloud SQL is provisioned, Data Connect service will transfer its data on a best-effort basis to the Cloud SQL instance. WARNING: Ephemeral data sources will expire after 24 hour. The data will be lost if they aren't transferred to the Cloud SQL instance. WARNING: When ephemeral=true, mutations to the database are not guaranteed to be durably persisted, even if an OK status code is returned. All or parts of the data may be lost or reverted to earlier versions. Corresponds to the JSON property ephemeral

Returns:

  • (Boolean)


1093
1094
1095
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1093

def ephemeral
  @ephemeral
end

#schemaString

Optional. User-configured PostgreSQL schema. Defaults to "public" if not specified. Corresponds to the JSON property schema

Returns:

  • (String)


1100
1101
1102
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1100

def schema
  @schema
end

#schema_migrationString

Optional. Configure how to perform Postgresql schema migration. Corresponds to the JSON property schemaMigration

Returns:

  • (String)


1105
1106
1107
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1105

def schema_migration
  @schema_migration
end

#schema_validationString

Optional. Configure how much Postgresql schema validation to perform. Corresponds to the JSON property schemaValidation

Returns:

  • (String)


1110
1111
1112
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1110

def schema_validation
  @schema_validation
end

#unlinkedBoolean Also known as: unlinked?

No Postgres data source is linked. If set, don't allow database and schema_validation to be configured. Corresponds to the JSON property unlinked

Returns:

  • (Boolean)


1116
1117
1118
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1116

def unlinked
  @unlinked
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1124
1125
1126
1127
1128
1129
1130
1131
1132
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1124

def update!(**args)
  @cloud_sql = args[:cloud_sql] if args.key?(:cloud_sql)
  @database = args[:database] if args.key?(:database)
  @ephemeral = args[:ephemeral] if args.key?(:ephemeral)
  @schema = args[:schema] if args.key?(:schema)
  @schema_migration = args[:schema_migration] if args.key?(:schema_migration)
  @schema_validation = args[:schema_validation] if args.key?(:schema_validation)
  @unlinked = args[:unlinked] if args.key?(:unlinked)
end