Class: Google::Apis::FirebasedataconnectV1::Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

The application schema of a Firebase SQL Connect service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schema

Returns a new instance of Schema.



1377
1378
1379
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Stores small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1318
1319
1320
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1318

def annotations
  @annotations
end

#create_timeString

Output only. [Output only] Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1323
1324
1325
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1323

def create_time
  @create_time
end

#datasourcesArray<Google::Apis::FirebasedataconnectV1::Datasource>

Required. The data sources linked in the schema. Corresponds to the JSON property datasources



1328
1329
1330
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1328

def datasources
  @datasources
end

#display_nameString

Optional. Mutable human-readable name. 63 character limit. Corresponds to the JSON property displayName

Returns:

  • (String)


1333
1334
1335
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1333

def display_name
  @display_name
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. AIP-154 Corresponds to the JSON property etag

Returns:

  • (String)


1341
1342
1343
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1341

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1346
1347
1348
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1346

def labels
  @labels
end

#nameString

Identifier. The relative resource name of the schema, in the format: projects/`project`/locations/`location`/services/`service`/schemas/`schema` Right now, the only supported schema is "main". Corresponds to the JSON property name

Returns:

  • (String)


1353
1354
1355
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1353

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that if true, indicates that the system is working to compile and deploy the schema. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1359
1360
1361
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1359

def reconciling
  @reconciling
end

#sourceGoogle::Apis::FirebasedataconnectV1::Source

Used to represent a set of source files. Corresponds to the JSON property source



1365
1366
1367
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1365

def source
  @source
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


1370
1371
1372
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1370

def uid
  @uid
end

#update_timeString

Output only. [Output only] Update time stamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


1375
1376
1377
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1375

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1382

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @datasources = args[:datasources] if args.key?(:datasources)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @source = args[:source] if args.key?(:source)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end