Class: Google::Apis::FirebasedataconnectV1::Schema
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
The application schema of a Firebase Data Connect service.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#datasources ⇒ Array<Google::Apis::FirebasedataconnectV1::Datasource>
Required.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#source ⇒ Google::Apis::FirebasedataconnectV1::Source
Used to represent a set of source files.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schema
constructor
A new instance of Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schema
Returns a new instance of Schema.
1201 1202 1203 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Stores small amounts of arbitrary data.
Corresponds to the JSON property annotations
1142 1143 1144 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1142 def annotations @annotations end |
#create_time ⇒ String
Output only. [Output only] Create time stamp.
Corresponds to the JSON property createTime
1147 1148 1149 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1147 def create_time @create_time end |
#datasources ⇒ Array<Google::Apis::FirebasedataconnectV1::Datasource>
Required. The data sources linked in the schema.
Corresponds to the JSON property datasources
1152 1153 1154 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1152 def datasources @datasources end |
#display_name ⇒ String
Optional. Mutable human-readable name. 63 character limit.
Corresponds to the JSON property displayName
1157 1158 1159 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1157 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding. AIP-154
Corresponds to the JSON property etag
1165 1166 1167 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1165 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
1170 1171 1172 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1170 def labels @labels end |
#name ⇒ String
Identifier. The relative resource name of the schema, in the format:
projects/`project`/locations/`location`/services/`service`/schemas/`schema`
Right now, the only supported schema is "main".
Corresponds to the JSON property name
1177 1178 1179 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1177 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. A field that if true, indicates that the system is working to
compile and deploy the schema.
Corresponds to the JSON property reconciling
1183 1184 1185 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1183 def reconciling @reconciling end |
#source ⇒ Google::Apis::FirebasedataconnectV1::Source
Used to represent a set of source files.
Corresponds to the JSON property source
1189 1190 1191 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1189 def source @source end |
#uid ⇒ String
Output only. System-assigned, unique identifier.
Corresponds to the JSON property uid
1194 1195 1196 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1194 def uid @uid end |
#update_time ⇒ String
Output only. [Output only] Update time stamp.
Corresponds to the JSON property updateTime
1199 1200 1201 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1199 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1206 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @datasources = args[:datasources] if args.key?(:datasources) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @source = args[:source] if args.key?(:source) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |