Class: Google::Apis::FirebasedataconnectV1::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

A Firebase Data Connect service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



1279
1280
1281
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Stores small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1228
1229
1230
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1228

def annotations
  @annotations
end

#create_timeString

Output only. [Output only] Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1233
1234
1235
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1233

def create_time
  @create_time
end

#display_nameString

Optional. Mutable human-readable name. 63 character limit. Corresponds to the JSON property displayName

Returns:

  • (String)


1238
1239
1240
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1238

def display_name
  @display_name
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. AIP-154 Corresponds to the JSON property etag

Returns:

  • (String)


1246
1247
1248
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1246

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1251
1252
1253
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1251

def labels
  @labels
end

#nameString

Identifier. The relative resource name of the Firebase Data Connect service, in the format: `projects/`project`/locations/`location`/services/`service` ` Note that the service ID is specific to Firebase Data Connect and does not correspond to any of the instance IDs of the underlying data source connections. Corresponds to the JSON property name

Returns:

  • (String)


1260
1261
1262
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1260

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that if true, indicates that the system is working update the service. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1266
1267
1268
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1266

def reconciling
  @reconciling
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


1272
1273
1274
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1272

def uid
  @uid
end

#update_timeString

Output only. [Output only] Update time stamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


1277
1278
1279
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1277

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1284

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end