Class: Google::Apis::FirebasedataconnectV1::Service
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb
Overview
A Firebase Data Connect service.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
1279 1280 1281 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Stores small amounts of arbitrary data.
Corresponds to the JSON property annotations
1228 1229 1230 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1228 def annotations @annotations end |
#create_time ⇒ String
Output only. [Output only] Create time stamp.
Corresponds to the JSON property createTime
1233 1234 1235 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1233 def create_time @create_time end |
#display_name ⇒ String
Optional. Mutable human-readable name. 63 character limit.
Corresponds to the JSON property displayName
1238 1239 1240 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1238 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding. AIP-154
Corresponds to the JSON property etag
1246 1247 1248 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1246 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
1251 1252 1253 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1251 def labels @labels end |
#name ⇒ String
Identifier. The relative resource name of the Firebase Data Connect service,
in the format: `projects/`project`/locations/`location`/services/`service` `
Note that the service ID is specific to Firebase Data Connect and does not
correspond to any of the instance IDs of the underlying data source
connections.
Corresponds to the JSON property name
1260 1261 1262 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1260 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. A field that if true, indicates that the system is working update
the service.
Corresponds to the JSON property reconciling
1266 1267 1268 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1266 def reconciling @reconciling end |
#uid ⇒ String
Output only. System-assigned, unique identifier.
Corresponds to the JSON property uid
1272 1273 1274 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1272 def uid @uid end |
#update_time ⇒ String
Output only. [Output only] Update time stamp.
Corresponds to the JSON property updateTime
1277 1278 1279 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1277 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1284 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |