Class: Google::Apis::FirebasedataconnectV1::Workaround

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1/classes.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb,
lib/google/apis/firebasedataconnect_v1/representations.rb

Overview

Workaround provides suggestions to address errors and warnings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Workaround

Returns a new instance of Workaround.



1399
1400
1401
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this workaround. Corresponds to the JSON property description

Returns:

  • (String)


1387
1388
1389
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1387

def description
  @description
end

#reasonString

Why would this workaround address the error and warning. Corresponds to the JSON property reason

Returns:

  • (String)


1392
1393
1394
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1392

def reason
  @reason
end

#replaceString

A suggested code snippet to fix the error and warning. Corresponds to the JSON property replace

Returns:

  • (String)


1397
1398
1399
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1397

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1404
1405
1406
1407
1408
# File 'lib/google/apis/firebasedataconnect_v1/classes.rb', line 1404

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @reason = args[:reason] if args.key?(:reason)
  @replace = args[:replace] if args.key?(:replace)
end